@@ -1,20 +1,9 @@
 /*
     This file is part of the KDE libraries
-    Copyright (C) 2007 Laurent Montel (montel@kde.org)
-    Copyright (C) 2007 Christian Ehrlicher (ch.ehrlicher@gmx.de)
+    SPDX-FileCopyrightText: 2007 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2007 Christian Ehrlicher <ch.ehrlicher@gmx.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "kwindowsystem.h"
@@ -83,7 +72,7 @@ public:
     void activate();
 
 protected:
-    bool nativeEvent(const QByteArray &eventType, void *message, long *result) Q_DECL_OVERRIDE;
+    bool nativeEvent(const QByteArray &eventType, void *message, long *result) override;
 
 private:
     bool activated;
@@ -447,7 +436,7 @@ void KWindowSystem::forceActiveWindow(WId win, long time)
     //to bring a window to the front while the user is active in a different apllication we
     //have to atach our self to the current active window
     HWND hwndActiveWin = GetForegroundWindow();
-    int  idActive      = GetWindowThreadProcessId(hwndActiveWin, NULL);
+    int  idActive      = GetWindowThreadProcessId(hwndActiveWin, nullptr);
     if (AttachThreadInput(GetCurrentThreadId(), idActive, TRUE)) {
         SetForegroundWindow(hwnd);
         SetFocus(hwnd);
@@ -489,7 +478,7 @@ QPixmap KWindowSystem::icon(WId win, int width, int height, bool scale)
             size = ICON_SMALL;
         }
         HICON hIcon = (HICON)SendMessage(reinterpret_cast<HWND>(win), WM_GETICON, size, 0);
-        if (hIcon != NULL) {
+        if (hIcon != nullptr) {
             pm = QtWin::fromHICON(hIcon);
         }
     }
@@ -596,7 +585,7 @@ void KWindowSystem::raiseWindow(WId win)
     //to bring a window to the front while the user is active in a different apllication we
     //have to atach our self to the current active window
     HWND hwndActiveWin = GetForegroundWindow();
-    int  idActive      = GetWindowThreadProcessId(hwndActiveWin, NULL);
+    int  idActive      = GetWindowThreadProcessId(hwndActiveWin, nullptr);
     if (AttachThreadInput(GetCurrentThreadId(), idActive, TRUE)) {
         SetForegroundWindow(reinterpret_cast<HWND>(win));
         AttachThreadInput(GetCurrentThreadId(), idActive, FALSE);
@@ -710,7 +699,7 @@ void KWindowSystem::setType(WId win, NET::WindowType windowType)
     qDebug() << "setType( WId win, NET::WindowType windowType ) isn't yet implemented!";
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 KWindowInfo KWindowSystem::windowInfo(WId win, unsigned long properties, unsigned long properties2)
 {
     KWindowSystem::init(INFO_WINDOWS);
